package com.jiuqi.grid;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.jiuqi.grid.GridCell;
import com.jiuqi.grid.GridData;
import com.jiuqi.grid.GridFontNames;
import com.jiuqi.grid.IntList;
import java.util.Stack;

final class GridCopyConvertor {
  GridData src;
  
  int[] fontNameMaps;
  
  int[] fontSizeMaps;
  
  int[] fontColorMaps;
  
  int[] cellColorMaps;
  
  int[] edgeColorMaps;
  
  private Stack freeFontNames;
  
  private Stack freeFontSizes;
  
  private Stack freeFontColors;
  
  private Stack freeCellColors;
  
  private Stack freeEdgeColors;
  
  public GridCopyConvertor(GridData src) {
    this.src = src;
    mergeFontNames(GridData.access$0(src));
    this.fontSizeMaps = mergeList(GridData.access$1(src), GridData.access$1(paramGridData1));
    this.fontColorMaps = mergeList(GridData.access$2(src), GridData.access$2(paramGridData1));
    this.cellColorMaps = mergeList(GridData.access$3(src), GridData.access$3(paramGridData1));
    this.edgeColorMaps = mergeList(GridData.access$4(src), GridData.access$4(paramGridData1));
  }
  
  private void mergeFontNames(GridFontNames srcFontNames) {
    boolean diff = false;
    int[] maps = new int[srcFontNames.count()];
    for (int i = 0; i < srcFontNames.count(); i++) {
      int index = GridData.access$0(GridData.this).indexOfFont(srcFontNames.getFont(i));
      maps[i] = index;
      if (i != index)
        diff = true; 
    } 
    this.fontNameMaps = diff ? maps : null;
  }
  
  private int[] mergeList(IntList srcList, IntList destList) {
    boolean diff = false;
    int[] maps = new int[srcList.count()];
    for (int i = 0; i < srcList.count(); i++) {
      int index = destList.indexOf(srcList.get(i));
      maps[i] = index;
      if (i != index)
        diff = true; 
    } 
    return diff ? maps : null;
  }
  
  public void convert(GridCell cell) {
    byte[] data = cell.getPropData();
    if (this.fontNameMaps != null) {
      int index = data[4] & 0x3F;
      int newIndex = mapFontName(index);
      data[4] = (byte)(data[4] & 0xC0 | newIndex & 0x3F);
    } 
    if (this.fontSizeMaps != null) {
      int index = data[5] & 0x3F;
      int newIndex = mapFontSize(index);
      data[5] = (byte)(data[5] & 0xC0 | newIndex & 0x3F);
    } 
    if (this.fontColorMaps != null) {
      int index = data[6] >> 0 & 0x3F;
      int newIndex = mapFontColor(index);
      data[6] = (byte)(data[6] & 0xC0 | newIndex & 0x3F);
    } 
    if (this.cellColorMaps != null) {
      int index = data[0];
      int newIndex = mapCellColor(index);
      data[0] = (byte)newIndex;
    } 
    if (this.edgeColorMaps != null) {
      int index = data[9] >> 4 & 0xF;
      int newIndex = mapEdgeColor(index);
      data[9] = (byte)(data[9] & 0xF | newIndex << 4 & 0xF0);
      index = data[10] >> 4 & 0xF;
      newIndex = mapEdgeColor(index);
      data[10] = (byte)(data[10] & 0xF | newIndex << 4 & 0xF0);
    } 
  }
  
  private int mapCellColor(int index) {
    int newIndex;
    if (this.cellColorMaps[index] == -1) {
      if (freeCellColors().isEmpty()) {
        newIndex = (GridData.access$3(GridData.this).count() >= 64) ? 0 : GridData.access$3(GridData.this).add(GridData.access$3(this.src).get(index));
      } else {
        newIndex = ((Integer)freeCellColors().pop()).intValue();
        GridData.access$3(GridData.this).set(newIndex, GridData.access$3(this.src).get(index));
      } 
      this.cellColorMaps[index] = newIndex;
    } else {
      newIndex = this.cellColorMaps[index];
    } 
    return newIndex;
  }
  
  private int mapFontColor(int index) {
    int newIndex;
    if (this.fontColorMaps[index] == -1) {
      if (freeFontColors().isEmpty()) {
        newIndex = (GridData.access$2(GridData.this).count() >= 64) ? 0 : GridData.access$2(GridData.this).add(GridData.access$2(this.src).get(index));
      } else {
        newIndex = ((Integer)freeFontColors().pop()).intValue();
        GridData.access$2(GridData.this).set(newIndex, GridData.access$2(this.src).get(index));
      } 
      this.fontColorMaps[index] = newIndex;
    } else {
      newIndex = this.fontColorMaps[index];
    } 
    return newIndex;
  }
  
  private int mapFontSize(int index) {
    int newIndex;
    if (this.fontSizeMaps[index] == -1) {
      if (freeFontSizes().isEmpty()) {
        newIndex = (GridData.access$1(GridData.this).count() >= 64) ? 0 : GridData.access$1(GridData.this).add(GridData.access$1(this.src).get(index));
      } else {
        newIndex = ((Integer)freeFontSizes().pop()).intValue();
        GridData.access$1(GridData.this).set(newIndex, GridData.access$1(this.src).get(index));
      } 
      this.fontSizeMaps[index] = newIndex;
    } else {
      newIndex = this.fontSizeMaps[index];
    } 
    return newIndex;
  }
  
  private int mapFontName(int index) {
    int newIndex;
    if (this.fontNameMaps[index] == -1) {
      if (freeFontNames().isEmpty()) {
        newIndex = (GridData.access$0(GridData.this).count() >= 64) ? 0 : GridData.access$0(GridData.this).addFont(GridData.access$0(this.src).getFont(index));
      } else {
        newIndex = ((Integer)freeFontNames().pop()).intValue();
        GridData.access$0(GridData.this).setFont(newIndex, GridData.access$0(this.src).getFont(index));
      } 
      this.fontNameMaps[index] = newIndex;
    } else {
      newIndex = this.fontNameMaps[index];
    } 
    return newIndex;
  }
  
  private int mapEdgeColor(int index) {
    int newIndex;
    if (this.edgeColorMaps[index] == -1) {
      if (freeEdgeColors().isEmpty()) {
        newIndex = (GridData.access$4(GridData.this).count() >= 64) ? 0 : GridData.access$4(GridData.this).add(GridData.access$4(this.src).get(index));
      } else {
        newIndex = ((Integer)freeEdgeColors().pop()).intValue();
        GridData.access$4(GridData.this).set(newIndex, GridData.access$4(this.src).get(index));
      } 
      this.edgeColorMaps[index] = newIndex;
    } else {
      newIndex = this.edgeColorMaps[index];
    } 
    return newIndex;
  }
  
  private Stack freeFontNames() {
    if (this.freeFontNames == null) {
      boolean[] flags = new boolean[GridData.access$0(GridData.this).count()];
      int i;
      for (i = 0; i < GridData.access$5(GridData.this).count(); i++) {
        byte[] data = GridData.access$5(GridData.this).get(i);
        int index = data[4] & 0x3F;
        flags[index] = true;
      } 
      this.freeFontNames = new Stack();
      for (i = 0; i < flags.length; i++) {
        if (!flags[i])
          this.freeFontNames.push(new Integer(i)); 
      } 
    } 
    return this.freeFontNames;
  }
  
  private Stack freeFontSizes() {
    if (this.freeFontSizes == null) {
      boolean[] flags = new boolean[GridData.access$1(GridData.this).count()];
      int i;
      for (i = 0; i < GridData.access$5(GridData.this).count(); i++) {
        byte[] data = GridData.access$5(GridData.this).get(i);
        int index = data[5] & 0x3F;
        flags[index] = true;
      } 
      this.freeFontSizes = new Stack();
      for (i = 0; i < flags.length; i++) {
        if (!flags[i])
          this.freeFontSizes.push(new Integer(i)); 
      } 
    } 
    return this.freeFontSizes;
  }
  
  private Stack freeFontColors() {
    if (this.freeFontColors == null) {
      boolean[] flags = new boolean[GridData.access$2(GridData.this).count()];
      int i;
      for (i = 0; i < GridData.access$5(GridData.this).count(); i++) {
        byte[] data = GridData.access$5(GridData.this).get(i);
        int index = data[6] >> 0 & 0x3F;
        flags[index] = true;
      } 
      this.freeFontColors = new Stack();
      for (i = 0; i < flags.length; i++) {
        if (!flags[i])
          this.freeFontColors.push(new Integer(i)); 
      } 
    } 
    return this.freeFontColors;
  }
  
  private Stack freeCellColors() {
    if (this.freeCellColors == null) {
      boolean[] flags = new boolean[GridData.access$3(GridData.this).count()];
      int i;
      for (i = 0; i < GridData.access$5(GridData.this).count(); i++) {
        byte[] data = GridData.access$5(GridData.this).get(i);
        flags[data[0]] = true;
      } 
      this.freeCellColors = new Stack();
      for (i = 0; i < flags.length; i++) {
        if (!flags[i])
          this.freeCellColors.push(new Integer(i)); 
      } 
    } 
    return this.freeCellColors;
  }
  
  private Stack freeEdgeColors() {
    if (this.freeEdgeColors == null) {
      boolean[] flags = new boolean[GridData.access$4(GridData.this).count()];
      int i;
      for (i = 0; i < GridData.access$5(GridData.this).count(); i++) {
        byte[] data = GridData.access$5(GridData.this).get(i);
        int index = data[9] >> 4 & 0xF;
        flags[index] = true;
        index = data[10] >> 4 & 0xF;
        flags[index] = true;
      } 
      this.freeEdgeColors = new Stack();
      for (i = 0; i < flags.length; i++) {
        if (!flags[i])
          this.freeEdgeColors.push(new Integer(i)); 
      } 
    } 
    return this.freeEdgeColors;
  }
}
